@@ -8,14 +8,13 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <zlib.h>
 
 #include "pure_constants.h"
 #include "pure_errors.h"
 #include "pure_signatures.h"
 #include "pure_routines.h"
 
-#include "zlib/zlib.h"
-
 typedef struct pure_ctx {
   uint64_t flags;
   uint64_t depth;
